@@ -1,6 +1,6 @@
 /* enchant
  * Copyright (C) 2003, 2004 Dom Lachowicz
- * Copyright (C) 2016-2023 Reuben Thomas <rrt@sc3d.org>
+ * Copyright (C) 2016-2024 Reuben Thomas <rrt@sc3d.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -345,10 +345,10 @@ enchant_dict_set_error (EnchantDict * dict, const char * const err)
 {
 	g_return_if_fail (dict);
 	g_return_if_fail (err);
-	g_return_if_fail (g_utf8_validate(err, -1, NULL));
 
 	EnchantSession * session = ((EnchantDictPrivateData*)dict->enchant_private_data)->session;
 	enchant_session_clear_error (session);
+	g_debug("enchant_dict_set_error: %s", err);
 	session->error = strdup (err);
 }
 
@@ -651,13 +651,6 @@ enchant_broker_clear_error (EnchantBroker * broker)
 		}
 }
 
-static void
-enchant_broker_set_error (EnchantBroker * broker, const char * const err)
-{
-	enchant_broker_clear_error (broker);
-	broker->error = strdup (err);
-}
-
 static int
 enchant_provider_is_valid(EnchantProvider * provider)
 {
@@ -1302,12 +1295,13 @@ enchant_provider_set_error (EnchantProvider * provider, const char * const err)
 {
 	g_return_if_fail (provider);
 	g_return_if_fail (err);
-	g_return_if_fail (g_utf8_validate(err, -1, NULL));
 
 	EnchantBroker * broker = provider->owner;
 	g_return_if_fail (broker);
 
-	enchant_broker_set_error (broker, err);
+	enchant_broker_clear_error (broker);
+	g_debug("enchant_provider_set_error: %s", err);
+	broker->error = strdup (err);
 }
 
 const char *
